#
# spec file for package molsketch
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1599
%define gcc_ver 9
%endif
%define srcname Molsketch
%define sover 1
%define soname %{sover}
Name:           molsketch
Version:        0.8.0
Release:        1.3
Summary:        2D molecular structures editor
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Chemistry
URL:            https://molsketch.sourceforge.net
Source0:        https://downloads.sourceforge.net/molsketch/Molsketch-%{version}-src.tar.gz
# PATCH-FIX-UPSTREAM molsketch-cmake-qt5-add-translation.patch badshah400@gmail.com -- Use qt5_add_translation instead of qt_add_translation with cmake
Patch0:         molsketch-cmake-qt5-add-translation.patch
# PATCH-FIX-UPSTREAM molsketch-include-numeric-header.patch badshah400@gmail.com -- Include numeric header for transform_reduce
Patch1:         molsketch-include-numeric-header.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc%{?gcc_ver}-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  rsvg-convert
BuildRequires:  update-desktop-files
BuildRequires:  (pkgconfig(openbabel-2.0) or pkgconfig(openbabel-3))
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)

%description
The purpose of this editor to help drawing molecules.
Features:
 * open, save and import in all formats supported by the OpenBabel library
 * export to Scalable Vector Graphics (SVG) and a number of common used bitmap
   formats
 * print and export your document to PDF

%package 	devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Provides:       lib%{name}%{soname} =  %{version}
Requires:       libqt5-qttools
BuildArch:      noarch

%description 	devel
2D molecular structures editor.

This package contains header files and libraries needed to develop
application that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
2D molecular structures editor.

Help documentation for %{name}.

%prep
%autosetup -n %{srcname}-%{version} -p1

%build
%cmake \
%if 0%{?gcc_ver}
  -DCMAKE_CXX_COMPILER:STRING=g++-%{gcc_ver} \
%endif
  -DMSK_INSTALL_DOCS:PATH="/share/doc/packages/%{name}" \
%{nil}

%cmake_build

%install
%cmake_install

for sz in 24 32 48 64 128 256 512
do
  rsvg-convert -o %{name}-${sz}.png -w ${sz} molsketch/images/molsketch.svg
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${sz}x${sz}/apps
  install -m0644 %{name}-${sz}.png %{buildroot}%{_datadir}/icons/hicolor/${sz}x${sz}/apps/%{name}.png
done

%suse_update_desktop_file -c %{name} %{name} "2D molecular structures editor" %{name} Education Chemistry

%fdupes -s %{buildroot}%{_datadir}

%files
%license COPYING
%doc CHANGELOG
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/molsketch.*
%{_datadir}/pixmaps/molsketch.xpm
%{_datadir}/icons/hicolor/scalable/mimetypes/*.svg
%{_datadir}/metainfo/net.sourceforge.molsketch.appdata.xml
%{_datadir}/mime/packages/molsketch.xml

%files devel
%{_includedir}/lib%{name}/

%files doc
%{_docdir}/%{name}/
%exclude %{_docdir}/molsketch/CHANGELOG

%changelog
* Tue Jul 11 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.8.0:
  * Reimplemented rendering of atom labels (should also fix
    bounding box issues for charges)
  * Enable build with Qt 6
  * Dark mode icons
- Add molsketch-include-numeric-header.patch: add numeric header
  and ensure std=c++17 is used during compilation.
- Use gcc9 for openSUSE Leap 15.x to use transform_reduce.
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.7.3:
  * New bond types
* Sun Aug 14 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Allow build against Open Babel 3: It is supported since 0.7.0.
* Sat Jan 29 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add molsketch-cmake-qt5-add-translation.patch: Use
  qt5_add_translation instead of qt_add_translation with cmake.
* Wed Jun  9 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.7.2:
  * Update location of OpenBabel adapter when updating Molsketch.
  * Minor fixes in translations build (cmake).
- Changes from version 0.7.1:
  * Copy and cut actions also copy SVG image.
  * Fixed compilation with Qt 5 versions before Qt 5.14.
  * Fixed inclusion of translations for library part for qmake
    build.
  * Fixed inclusion of all translations for cmake build.
  * Fixed crashes/errors during copy/cut/paste and when opening
    files.
  * Removed support for Qt 4; filenames changed.
- Drop fix-compilation.patch: fixed upstream.
- New BuildRequires: cmake(Qt5LinguistTools).
- Adapt to upstream file name changes.
* Sat Jan 23 2021 Matthias Mailänder <mailaender@opensuse.org>
- Put essential libraries in the main package
* Sat Jan  2 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 0.7.0
  * New localizations: Greek, German, and Chinese
  * Direction of attached hydrogen atoms can be set explicitly by user
  * Atom shape can also be a circle instead of a rectangle
  * Bitmap export with adjustable resolution
  * Support OpenBabel 3
  * Fixes for sum formula and molecule tooltip
  * Fix clipping of bonds
  * Fixed OpenBabel support
- Add fix-compilation.patch
* Thu May  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.6.0:
  * Levels on which items are drawn are accessible; bonds are
    indicated to cover other bonds if on higher level
  * Broken bond indicator with same color as rest of bond
  * Show sum formula of molecule during hover and after selection
  * Closable wiki query
  * Improved performance for drag-and-drop insertion of molecules
  * Associated *.msm files with Molsketch
  * Fixed crashes after undo/redo (changed linkage between
    molecule, bonds, atoms)
  * Fixed global preferences (accidentally had no effect)
  * Fixed number of hydrogens and charge in saving/loading
    molecules
- Update options passed to cmake to keep up with upstream changes;
  omit MSK_INSTALL_LIBS specification entrirely since specifying
  it leads to installation of *.so into a subdir for x86_64 and
  directly into %%{_lib} for i586.
- Force ascii mode when using dos2unix.
- Drop conditionals for obsolete openSUSE versions.
- Drop shared lib package: versioned shared libraries are no
  longer installed, so everything is packaged in -devel.
* Thu Feb 20 2020 Max Lin <mlin@suse.com>
- Leap 15.2 and SLE15 SP2 has newer librsvg, extend the conditional
  for "BuildRequires: rsvg-convert"
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Tue Jan  9 2018 badshah400@gmail.com
- Update to version 0.5.1.
  * Newman radius of atom to draw Newman-type projections.
  * New tools for aligning, spacing, and cleaning up molecules.
  * Better encapsulate calls to OpenBabel to avoid crashes.
  * Several fixes to qmake/cmake installation of files (including
    MIME types).
- Drop molsketch-cmake-incorrect-file-loc.patch: incorporated
  upstream.
- Use rsvg-convert instead of inkscape for the svg-to-png
  conversion of icons; reduces the large number of build
  dependencies otherwise required for inkscape alone.
- Only run post(un) scriptlets for openSUSE <= 1320; for newer
  openSUSE these are automatically taken care of by rpm triggers;
  where applicable also run mime_database_post(un) as part of
  these scriptlets since molsketch now installs a mime file.
* Fri Dec 29 2017 jengelh@inai.de
- Trim (tm) symbol. Trim filler wording from description.
* Mon Oct  9 2017 badshah400@gmail.com
- Update to version 0.5.0:
  * Change log displayed on startup.
  * Lone pairs and radical electrons.
  * Selection by type (not yet really useful as properties are
    usually edited only for single items).
  * Querying Wikidata for chemical structures (requires
    OpenBabel and InChI support).
- Add molsketch-cmake-incorrect-file-loc.patch: Fix cmake install
  command looking for files in molsketch/src/* whereas they have
  been moved to molsketch/* already
- Build against Qt5 unconditionally (the minimum Qt5 is available
  across all supported openSUSE versions).
- Adapt file list for update: include files no longer installed
* Thu Aug 17 2017 badshah400@gmail.com
- Update to 0.4.1:
  * A new text tool.
  * Cmake build now offers the option to turn off OpenBabel
    support, which was previously only possible with qmake.
  * Legacy stereo bonds (from files created with versions prior to
    Lithium) are now imported correctly.
- Use inkscape to build hicolor png icons from bundled svg image
  and install then all.
- Run post install scripts to update desktop database and hicolor
  icon theme.
- Run spec-cleaner for a clean-up.
* Thu Oct 22 2015 avvissu@yandex.ru
- Update to 0.3.0:
  * see: /usr/share/doc/packages/molsketch/CHANGELOG
- Create a new spec file for building RPM
- Use qmake instead of cmake
- Add new packages: libmolsketch, molsketch-doc, molsketch-devel
* Sat Jul  7 2012 scorot@free.fr
- fix build on SLE 11
* Sat Jul  7 2012 scorot@free.fr
- fix openbabel dependency according to package name changes
* Sat Feb 25 2012 mailaender@opensuse.org
- update to version 2.0.0 with fixes from git by the developer
* Tue Feb 21 2012 mailaender@opensuse.org
- initial packaging, added QtAssistant include path to CMakeLists.txt
- added BuildRequires: -post-build-checks because of compiler warnings
